@@ -1,12 +1,13 @@
-"cca.formula" <-
-function (formula, data, ...) 
+`cca.formula` <-
+    function (formula, data, na.action = na.fail, subset = NULL, ...) 
 {
     if (missing(data)) {
         data <- parent.frame()
     } else {
         data <- ordiGetData(match.call(), environment(formula))
     }
-    d <- ordiParseFormula(formula, data)
+    d <- ordiParseFormula(formula, data, na.action = na.action,
+                          subset = substitute(subset))
     sol <- cca.default(d$X, d$Y, d$Z)
     if (!is.null(sol$CCA)) 
         sol$CCA$centroids <- centroids.cca(sol$CCA$wa, d$modelframe, 
@@ -19,9 +20,12 @@ function (formula, data, ...)
             drop = FALSE]
     }
     sol$terms <- d$terms
-    sol$terminfo <- ordiTerminfo(d, data)
+    sol$terminfo <- ordiTerminfo(d, d$modelframe)
+    sol$na.action <- d$na.action
     sol$call <- match.call()
     sol$call[[1]] <- as.name("cca")
     sol$call$formula <- formula(d$terms, width.cutoff = 500)
+    if (!is.null(sol$na.action))
+        sol <- ordiNAexclude(sol, d$excluded)
     sol
 }
