@@ -3,6 +3,6 @@
 {
     cat("\nCall:\n")
     cat(deparse(x$call), "\n\n")
-    printCoefmat(x$aov.tab, eps = 1/nrow(x$f.perms), na.print = "")
+    printCoefmat(x$aov.tab,  na.print = "")
     invisible(x)
 }
