@@ -1,6 +1,8 @@
 tsallis <-
-function (x, scales = seq(0, 2, 0.2), norm=FALSE)
+function (x, scales = seq(0, 2, 0.2), norm=FALSE, hill=FALSE)
 {
+    if (norm && hill)
+        stop("'norm = TRUE' and 'hill = TRUE' should not be used at the same time")
     x <- as.matrix(x)
     n <- nrow(x)
     p <- ncol(x)
@@ -26,6 +28,13 @@ function (x, scales = seq(0, 2, 0.2), norm=FALSE)
             if (scales[a] == 1) result[, a] <- result[, a] / log(ST)
             else result[, a] <- result[, a] / ((ST^(1-scales[a]) - 1) / (1 - scales[a]))
         }
+        if (hill) {
+            result[, a] <- if (scales[a] == 1) {
+                exp(result[, a])
+            } else {
+                (1 - (scales[a] - 1) * result[, a])^(1/(1-scales[a]))
+            }
+        }
     }
     result <- as.data.frame(result)
     if (any(dim(result) == 1)) 
